<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>KvManager::AboutDialog</name>
    <message>
        <location filename="../../about.ui" line="135"/>
        <source>License</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>KvManager::KvantumManager</name>
    <message>
        <location filename="../../kvantummanager.ui" line="12"/>
        <source>Kvantum Manager</source>
        <translation>Menedżer Kvantum</translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="38"/>
        <source>Install/Update Theme</source>
        <translation>Instaluj/aktualizuj motyw</translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="44"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;i&gt;Kvantum&lt;/i&gt;&lt;/b&gt; comes with many themes but external themes can also be installed for being used by it. Here you could choose a theme folder and then press the button below to install it in your Home.&lt;/center&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="76"/>
        <source>Select a Kvantum
theme folder</source>
        <translation>Wybierz folder
motywów Kvantum</translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="113"/>
        <source>Add this theme to the list of themes that
Kvantum can use in addition to its own themes.</source>
        <translation>Dodaj ten motyw do listy motywów
używanych przez Kvantum.</translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="117"/>
        <source>Install this theme</source>
        <translation>Zainstaluj ten motyw</translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="138"/>
        <source>Change/Delete Theme</source>
        <translation>Zmień/usuń motyw</translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="144"/>
        <source>Select a theme:</source>
        <translation>Wybierz motyw:</translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="191"/>
        <source>Delete this theme</source>
        <translation>Usuń ten motyw</translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="198"/>
        <source>Make Kvantum use this theme!

A disabled button means that
the theme is already used.</source>
        <translation>Spraw, aby Kvantum używał tego motywu!

Nieaktywny przycisk oznacza,
że ten motyw jest aktualnie używany.</translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="204"/>
        <source>Use this theme</source>
        <translation>Użyj tego motywu</translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="257"/>
        <source>Configure Active Theme</source>
        <translation>Konfiguruj aktywny motyw</translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="321"/>
        <source>Revert to the default (root)
settings of this theme.
(Ctrl+Z)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="326"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Revert to the default (root) settings of this theme!&lt;/p&gt;&lt;p&gt;When clicked and confirmed, all changes to the configuration will be lost but the probable customized SVG file will remain intact.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="329"/>
        <source>Restore</source>
        <translation>Przywróć</translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="332"/>
        <source>Ctrl+Z</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="339"/>
        <source>Save this configuration
(Ctrl+S)</source>
        <translation>Zapisz tą konfigurację
(Ctrl+S)</translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="343"/>
        <location filename="../../kvantummanager.ui" line="2086"/>
        <source>Save</source>
        <translation>Zapisz</translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="346"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="353"/>
        <source>Safe Settings</source>
        <translation>Bezpieczne ustawienia</translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="366"/>
        <source>Uncheck all these boxes if you want all
widgets to appear as they are by default.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="370"/>
        <source>Hacks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="394"/>
        <source>Transparent Dolphin view</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="422"/>
        <source>Normal font for default push buttons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="442"/>
        <source>Merge PCManFM-qt&apos;s sidepane with its surroundings.

Under LXQt, it needs logging out and in or closing
PCManFM-qt and then, stopping and starting Desktop
with LXQt Session Settings.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="449"/>
        <source>Transparent sidepane for PCManFM-qt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="464"/>
        <source>Iconless push buttons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="471"/>
        <source>Merge PCManFM-qt&apos;s view with its surroundings.

Under LXQt, it needs logging out and in or closing
PCManFM-qt and then, stopping and starting Desktop
with LXQt Session Settings.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="478"/>
        <source>Transparent view for PCManFM-qt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="493"/>
        <source>Iconless menus</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="508"/>
        <source>Blur explicitly translucent windows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="522"/>
        <source>Single top toolbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="529"/>
        <source>Do not draw any background for KTitles.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="532"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Do not draw any background for KTitles?&lt;/p&gt;&lt;p&gt;Ktitles are used by some KDE applications to show different sections in configuration dialogs.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="535"/>
        <source>Transparent KTitle label</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="542"/>
        <source>Do not tint selected label icons with
the highlight color!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="546"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;By default, selected label icons are tinted by the highlight color.&lt;/p&gt;&lt;p&gt;Checking this box removes the tint.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="549"/>
        <source>No selection tint</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="556"/>
        <source>Do not draw any background for (KDE) menu titles.
(Needs Logging out and in for Plasma menus.)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="560"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Do not draw any background for (KDE) menu titles?&lt;/p&gt;&lt;p&gt;Menu titles are like menu separators but with icon and text.&lt;/p&gt;&lt;p&gt;This needs Logging out and in for KDE Plasma menus. For LXQt panel, a panel restart with &lt;span style=&quot; font-style:italic;&quot;&gt;Session Settings &lt;/span&gt;is enough.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="563"/>
        <source>Transparent menu title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="570"/>
        <source>Text colors are defined by the theme
and can have translucency.

Checking this is not recommended unless
as a workaround for bugs in applications.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="577"/>
        <source>Opaque (text) colors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="584"/>
        <source>Style KDE capacity bars as progressbars.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="587"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Style KDE capacity bars as progressbars?&lt;/p&gt;&lt;p&gt;Capacity bars are usually used by some KDE applications to show volume sizes and have their own style.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="590"/>
        <source>Show KCapacityBar as progressbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="597"/>
        <source>This is not a complete fix but prevents
annoying scroll jumps that may happen
with the mouse wheel when mouse gestures
are enabled.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="603"/>
        <source>Workaround for Qt&apos;s scroll jump bug</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="629"/>
        <source>Tint label icons on mouseover by </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="643"/>
        <location filename="../../kvantummanager.ui" line="690"/>
        <location filename="../../kvantummanager.ui" line="1012"/>
        <location filename="../../kvantummanager.ui" line="1045"/>
        <source> %</source>
        <translation> %</translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="615"/>
        <source>Respect dark themes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="667"/>
        <location filename="../../kvantummanager.ui" line="682"/>
        <source>Useful with monochrome icon sets and
when the opacity of disabled icons is not
reduced by other means.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="672"/>
        <location filename="../../kvantummanager.ui" line="687"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Useful with monochrome icon sets and when the opacity of disabled icons is not reduced by other means.&lt;/p&gt;&lt;p&gt;KDE automatically reduces the opacity of disabled icons. Therefore, this option might be useful rather under other desktop environments.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="675"/>
        <source>Opacity of disabled icons:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="653"/>
        <source>Show size grips of dialogs and statusbars
as far as possible.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="657"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Show size grips of dialogs and statusbars as far as possible?&lt;/p&gt;&lt;p&gt;By default, the application decides whether they should be shown, but this hack could be useful for resizing windows easily when there is no window border.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="660"/>
        <source>Force size grips</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="722"/>
        <source>LXQt main menu icon size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="737"/>
        <location filename="../../kvantummanager.ui" line="1182"/>
        <location filename="../../kvantummanager.ui" line="1220"/>
        <location filename="../../kvantummanager.ui" line="1250"/>
        <location filename="../../kvantummanager.ui" line="1284"/>
        <location filename="../../kvantummanager.ui" line="1312"/>
        <location filename="../../kvantummanager.ui" line="1338"/>
        <location filename="../../kvantummanager.ui" line="1368"/>
        <location filename="../../kvantummanager.ui" line="1396"/>
        <location filename="../../kvantummanager.ui" line="1431"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="751"/>
        <source>Compositing &amp;&amp; General Look</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="907"/>
        <source>Has effect only when there is a translucent SVG background
for windows or the window opacity is reduced (see below).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="925"/>
        <source>Opaque apps:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="757"/>
        <source>If checked, menus, tooltips and windows
will not have translucency or shadow.

If this is disabled, see:
Miscellaneous → Respect current DE if possible</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="227"/>
        <source>&lt;br&gt;&lt;br&gt;Since &lt;b&gt;&lt;i&gt;Kvantum&lt;/i&gt;&lt;/b&gt; is independent of all desktop environments, you first need to &lt;i&gt;activate&lt;/i&gt; it with a Qt platform integration program. KDE and LXQt provide simple tools for changing the active Qt style plugin. With other platforms, you need a Qt configuration tool.&lt;br/&gt;&lt;br/&gt;Under KDE, also select and apply the color scheme of this theme because some KDE applications may get their colors directly from the KDE color scheme.&lt;br/&gt;&lt;br/&gt;Running applications will get the new theme after being closed and reopened. Logging out and in would be good for all KDE/LXQt parts to see it completely.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="703"/>
        <source>By default, the scroll slider jumps to a position
when the scrollbar is left clicked.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="707"/>
        <source>Scroll jump with middle click</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="714"/>
        <location filename="../../kvantummanager.ui" line="729"/>
        <source>Has effect only when the main menu is NOT styled by LXQt.

Values less than 16 mean the default menu icon size.

Needs LXQt panel to be restarted either by &quot;Session Settings&quot;
or through logging out and in again.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="764"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;If checked, menus, tooltips and windows will not have translucency or shadow.&lt;/p&gt;&lt;p&gt;When unchecked, translucency and shadow will be available if there are appropriate elements in the theme&apos;s SVG file.&lt;/p&gt;&lt;p&gt;If this is disabled, see Miscellaneous → Respect current DE if possible.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="767"/>
        <source>Disable composite effects</source>
        <translation>Wyłącz efekty kompozytowania</translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="776"/>
        <source>This needs the KDE contrast effect with Qt ≥ 5.11
and is applied only to translucent windows that
support the blur effect (but the KDE blur effect
can be disabled).

A value of 1.00 means no change.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="784"/>
        <source>Contrast Effect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="790"/>
        <source>Saturation:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="797"/>
        <source>Intensity:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="804"/>
        <source>Contrast:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="881"/>
        <source>Needs KDE blur effect, a graphic card that supports it,
and translucent menu/tooltip SVG elements.

Automatically checked if window blurring is enabled.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="887"/>
        <source>Blurring for menus and tooltips</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="894"/>
        <source>Do not draw shadows for menus and tooltips.

This may be useful under DEs that give
shadow to menus and tooltips.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="900"/>
        <source>Shadowless menus and tooltips</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="911"/>
        <source>Translucent windows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="975"/>
        <location filename="../../kvantummanager.ui" line="1005"/>
        <source>This will reduce the window opacity
if window translucency is enabled.

A translucent SVG background is NOT
needed for this key to work.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="982"/>
        <source>Reduce window opacity by</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1022"/>
        <source>Reduce menu opacity by</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1060"/>
        <source>Blurring for translucent windows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1080"/>
        <source>A 200ms fading animation when the state of
some widgets is changed, mostly by the mouse.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1084"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;A 200ms fading animation when the state of some widgets is changed, mostly by the mouse.&lt;/p&gt;&lt;p&gt;The CPU usage is negligible because often only one widget is animated. The resulting visual effect depends on the active theme.&lt;/p&gt;&lt;p&gt;These widgets are supported: buttons (including radio buttons and check boxes), combo boxes, spin boxes, slider handles, line-edits and scroll views.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1087"/>
        <source>Animation for state change under mouse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1094"/>
        <source>Check this to remove all window/dialog tiling patterns!
Uncheck it if you want those patterns back!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1098"/>
        <source>Remove window/dialog tiling patterns</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1105"/>
        <source>Use the same colors and shapes with active and inactive
windows if this theme distinguishes between them?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1109"/>
        <source>Ignore inactive state</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1123"/>
        <source>Transient scrollbars</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1145"/>
        <source>Sizes &amp;&amp; Delays</source>
        <translation>Rozmiary i odstępy</translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1151"/>
        <source>Sizes</source>
        <translation>Rozmiary</translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1166"/>
        <source>Small icon:</source>
        <translation>Mała ikona:</translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1204"/>
        <source>Large icon:</source>
        <translation>Duża ikona:</translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1238"/>
        <source>Button icon:</source>
        <translation>Ikona przycisku:</translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1270"/>
        <source>Toolbar icon:</source>
        <translation>Ikona paska zadań:</translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1297"/>
        <location filename="../../kvantummanager.ui" line="1308"/>
        <source>The default value is 2 px but
some apps set it themeselves.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1301"/>
        <source>Layout spacing:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1325"/>
        <location filename="../../kvantummanager.ui" line="1335"/>
        <source>The default value is 4 px but some apps set it themeselves.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1328"/>
        <source>Layout margin:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1351"/>
        <location filename="../../kvantummanager.ui" line="1363"/>
        <source>The horizontal overlap between a submenu and its parent.

0 by default.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1356"/>
        <source>Submenu overlap: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1381"/>
        <location filename="../../kvantummanager.ui" line="1392"/>
        <source>The width of horizontal spin buttons.
(Has no effect when spin indicators are vertical.)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1385"/>
        <source>Spin button width: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1583"/>
        <source>Draw tree branch lines?

By default, tree branches have indicators but no line.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1897"/>
        <source>Dialog button layout:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1907"/>
        <source>They may look like dotted rectangles
on focused buttons and other widgets.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1911"/>
        <source>Remove focus rectangles</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="2068"/>
        <source>Use the active theme for all apps!

This Needs saving to take effect.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="183"/>
        <source>Remove the selected theme
from all user installation paths.

The root installation will still be
available if present; this button
only removes user themes.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="389"/>
        <source>Merge Dolphin&apos;s view with its surroundings?

By default, it has the base background.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="417"/>
        <source>No bold font for default push buttons?

Such push buttons have bold text by default.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="456"/>
        <source>No icon for push buttons that have text?

By default, most push buttons have icon.

If this is disabled, see:
Miscellaneous → Respect current DE if possible</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="485"/>
        <source>No icon for menu-items?

By default, some of them may have icon.

If this is disabled, see:
Miscellaneous → Respect current DE if possible</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="500"/>
        <source>Blur the regions behind windows that are made
translucent by their apps explicitly if possible.

This needs the KDE blur effect.

Konsole, QTerminal and LXQt panel are some examples.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="515"/>
        <source>Only the top toolbar should be styled?

By default, all toolbars are styled,
whether they are on the top or at any
other position.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="622"/>
        <location filename="../../kvantummanager.ui" line="636"/>
        <source>The highlight color is used for tinting.

This is mostly relevant with monochrome icons.

Hard-coded icons/styles may not respect this key.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="610"/>
        <source>Some apps may not respect dark themes.
Kvantum can try to correct their behavior
as far as possible.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1055"/>
        <source>Needs KDE blur effect, a graphic card
that supports it, and a translucent
window SVG background in the theme.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1133"/>
        <source>Should transient scrollbars have
semi-transparent grooves when needed?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1137"/>
        <source>Transient scrollbar grooves when needed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1157"/>
        <location filename="../../kvantummanager.ui" line="1173"/>
        <source>Affects menu-items and headers.

The default value is 16 px but
some apps may set it themselves.

If this is disabled, see:
Miscellaneous → Respect current DE if possible</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1195"/>
        <location filename="../../kvantummanager.ui" line="1211"/>
        <source>Affects icon views.

The default value is 32 px but
some apps set it themselves.

If this is disabled, see:
Miscellaneous → Respect current DE if possible</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1233"/>
        <location filename="../../kvantummanager.ui" line="1245"/>
        <source>Affects buttons, tab-bars and list-views.

The default value is 16 px.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1263"/>
        <location filename="../../kvantummanager.ui" line="1277"/>
        <source>Affects toolbars.

The default value is 22 px but
some apps set it themselves.
KDE apps get it from KDE setting.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1412"/>
        <location filename="../../kvantummanager.ui" line="1425"/>
        <source>The minimum length of scrollbars.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1415"/>
        <location filename="../../kvantummanager.ui" line="1428"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;The minimum height of vertical scrollbars and the minimum width of horizontal scrollbars.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1418"/>
        <source>Minimum scrollbar length: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1463"/>
        <source>Delays</source>
        <translation>Odstępy</translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1469"/>
        <location filename="../../kvantummanager.ui" line="1497"/>
        <source>The delay, in milliseconds, before a tooltip is shown.

Zero means tooltips are shown instantly.

-1 means the default Qt behavior.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1811"/>
        <source>Scrollbars have add-line and sub-line arrows by default.

Checking this box removes arrows as far as possible.

If disabled, see Compositing &amp; General Look → Transient scrollbars!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1664"/>
        <source>By default, drop rectangles for movable
toolbars and dock widgets are hollow.

This option fills drop rectangles with
the highlight color.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1718"/>
        <source>If checked, the menubar and toolbar will be drawn as a whole by
the toolbar SVG element when they are adjacent to each another.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1764"/>
        <source>Shift the contents of push buttons when pressed?

By default, the contents are shifted by 1px
both horizontally and vertically.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1918"/>
        <location filename="../../kvantummanager.ui" line="1932"/>
        <source>Drag windows from their menubars, primary toolbars
or anywhere possible (and not only from their title bars)?

If this is disabled, see:
Miscellaneous → Respect current DE if possible</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1841"/>
        <location filename="../../kvantummanager.ui" line="1860"/>
        <source>Will have effect only if style
is not set by the app in its code.

Default is &quot;Follow Style&quot;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1623"/>
        <source>By default, spin indicators are drawn as
two buttons with arrows or plus/minus signs.

Checking this integrates the spin indicators
into the spin line-edit..</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1595"/>
        <source>Activate view items always on double clicking?

When unchecked, single-click is preferred.

If this is disabled, see:
Miscellaneous → Respect current DE if possible</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1651"/>
        <source>By default, spin indicators are drawn on adjacent buttons.

Checking this puts the spin-up indicator above the
spin-down one inside the spin line-edit.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1706"/>
        <source>Draw combo popups as menu popups (i.e. like in Gtk)?

By default, combo popups do not cover the combo box.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1754"/>
        <source>In Kvantum, tabs are centered by default.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1610"/>
        <source>Should big menus be scrollable and have
scroll arrows on their top and/or bottom?

By default, all of their menu-items are shown.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1476"/>
        <source>Tooltip delay:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="918"/>
        <location filename="../../kvantummanager.ui" line="948"/>
        <source>A comma-separated list of executables,
whose windows should not be translucent.

(Some apps, like video players, may have
problems with translucency!)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1116"/>
        <source>Make scrollbars transient!

Transient scrollbars appear on top of
their scroll views only when needed.
They usually take no extra space.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1483"/>
        <location filename="../../kvantummanager.ui" line="1520"/>
        <source>The delay, in milliseconds, to wait before opening a submenu.
250 by default.

-1 means no popup (opening by clicking),
while 0 means no delay.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1490"/>
        <source>Submenu delay: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1504"/>
        <location filename="../../kvantummanager.ui" line="1527"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1560"/>
        <source>Miscellaneous</source>
        <translation>Różne</translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1818"/>
        <source>No arrows for scrollbars</source>
        <translation>Brak strzałek na pasku przewijania</translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1883"/>
        <source>Draw scrollbars inside view frames?

By default, scrollbars are drawn outide view frames.

If disabled, see Compositing &amp; General Look → Transient scrollbars!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1890"/>
        <source>Scrollbars inside frames</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1588"/>
        <source>Tree branch lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1637"/>
        <source>By default, the label is on the frame
and the frame is cut to contain it.

Checking this puts the label right above
the frame, so that the frame isn&apos;t cut.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1644"/>
        <source>Group-box label above frame</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1671"/>
        <source>Fill rubber-band rectangles</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1692"/>
        <source>Mouse tracking is enabled
for menubars by default.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1696"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Mouse tracking is enabled for menubars by default, i.e., after a menubar item is clicked and its menu is shown, the menus of the other menubar items will be shown if the cursor is put on them without clicking.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1699"/>
        <source>Mouse tracking for menubars</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1722"/>
        <source>Merge menubar with toolbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1743"/>
        <source>If checked, toolbar buttons will be drawn grouped and raised
between toolbar separators.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1747"/>
        <source>Group toolbar buttons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1770"/>
        <source>Shift push-button contents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1925"/>
        <source>Drag from:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1847"/>
        <source>Toolbutton style:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1788"/>
        <source>If unchecked, shortcuts will not be underlined at all.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1791"/>
        <source>Underline shortcuts with Alt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1630"/>
        <source>Inline spin indicators</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1678"/>
        <source>Draw the whole editable combo-box as a
line-edit with arrow (and icon, if it exists)?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1682"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Draw the whole editable combo-box as a line-edit with arrow (and icon, if it exists)?&lt;/p&gt;&lt;p&gt;By default, a combo-box consists of a line-edit, a button with arrow on one side and another button with icon on the other side.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1685"/>
        <source>Editable combo as line-edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1603"/>
        <source>Double-click for view items</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1657"/>
        <source>Vertical spin indicators</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1566"/>
        <source>When this is enabled and checked, Kvantum will try to
respect some settings of the current desktop environment.

This checkbox may disable some options.
Uncheck it if you want to use those options!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1576"/>
        <source>Respect current DE if possible</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1711"/>
        <source>Combo popup as menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1757"/>
        <source>Left aligned tabs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1777"/>
        <source>Inactive tabs are joined together by default,
i.e., there is no border between them.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1781"/>
        <source>Join inactive tabs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1616"/>
        <source>Scrollable menus</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1573"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;When this is enabled and checked, Kvantum will try to respect some settings of the current desktop environment if it is KDE, Unity, Gnome or Pantheon.&lt;/p&gt;&lt;p&gt;Under KDE, it makes Kvantum read KDE settings for small and large icon sizes and also single or double clicking.&lt;/p&gt;&lt;p&gt;Under Unity, Gnome and Pantheon, it removes icons from menus and push-buttons (even if the corresponding dconf keys are changed) and disables window translucency.&lt;/p&gt;&lt;p&gt;This checkbox may disable some options. Uncheck it if you want to use those options!&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1729"/>
        <source>When drawing combo popups as menus,
there will be a checkbox next to each entry
(although Kvantum draws it as a radio button).

This option will hide these.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1736"/>
        <source>Non-checkable combo menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1959"/>
        <source>Application Themes</source>
        <translation>Motywy aplikacji</translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="1965"/>
        <source>&lt;center&gt;Here you could assign themes to specific applications.&lt;/center&gt;&lt;br&gt;&lt;center&gt;For each theme, you could add a comma-separated list of executables whose applications should use that theme instead of the active theme. After doing so for all of your chosen themes, save the result by clicking on the &lt;i&gt;Save&lt;/i&gt; button!&lt;/center&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="2000"/>
        <source>Installed Theme</source>
        <translation>Zainstalowany motyw</translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="2016"/>
        <source>Application(s)</source>
        <translation>Aplikacja/e</translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="2045"/>
        <source>app1,app2,app3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="2073"/>
        <source>Remove List</source>
        <translation>Usuń listę</translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="2080"/>
        <source>Save the current list of apps</source>
        <translation>Zapisz obecną listę aplikacji</translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="2083"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Save the current list of applications with their corresponding themes!&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="2110"/>
        <location filename="../../kvantummanager.ui" line="2116"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="2113"/>
        <source>Quit</source>
        <translation>Zakończ</translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="2126"/>
        <source>Preview the active theme
or update its preview.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="2130"/>
        <source>Preview</source>
        <translation>Podgląd</translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="2137"/>
        <source>About</source>
        <translation>O programie</translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="2160"/>
        <source>What&apos;s This?</source>
        <translation>Co to jest?</translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="2163"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Click on this button and then click on a GUI element that has &amp;quot;What&apos;s This&amp;quot; tooltip  to get information about what it does.&lt;/p&gt;&lt;p&gt;There are also ordinary tooltips but this kind of tooltip will not disappear until you click somewhere.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../kvantummanager.ui" line="2166"/>
        <source>Help</source>
        <translation>Pomoc</translation>
    </message>
    <message>
        <location filename="../../KvantumManager.cpp" line="195"/>
        <source>Open Kvantum Theme Folder...</source>
        <translation>Otwórz folder motywów Kvantum…</translation>
    </message>
    <message>
        <location filename="../../KvantumManager.cpp" line="382"/>
        <location filename="../../KvantumManager.cpp" line="399"/>
        <location filename="../../KvantumManager.cpp" line="415"/>
        <location filename="../../KvantumManager.cpp" line="426"/>
        <location filename="../../KvantumManager.cpp" line="437"/>
        <location filename="../../KvantumManager.cpp" line="464"/>
        <location filename="../../KvantumManager.cpp" line="479"/>
        <location filename="../../KvantumManager.cpp" line="526"/>
        <location filename="../../KvantumManager.cpp" line="542"/>
        <source>Kvantum</source>
        <translation>Kvantum</translation>
    </message>
    <message>
        <location filename="../../KvantumManager.cpp" line="466"/>
        <source>First you have to delete its modified version!</source>
        <translation>Musisz najpierw usunąć zmodyfikowaną wersję!</translation>
    </message>
    <message>
        <location filename="../../KvantumManager.cpp" line="490"/>
        <location filename="../../KvantumManager.cpp" line="644"/>
        <location filename="../../KvantumManager.cpp" line="2480"/>
        <source>Confirmation</source>
        <translation>Potwierdzenie</translation>
    </message>
    <message>
        <location filename="../../KvantumManager.cpp" line="605"/>
        <source>%1 installed.</source>
        <translation>Zainstalowano %1.</translation>
    </message>
    <message>
        <location filename="../../KvantumManager.cpp" line="775"/>
        <source>%1 deleted.</source>
        <translation>Usunięto %1.</translation>
    </message>
    <message>
        <location filename="../../KvantumManager.cpp" line="829"/>
        <source>Theme changed to %1.</source>
        <translation>Zmieniono motyw na %1.</translation>
    </message>
    <message>
        <location filename="../../KvantumManager.cpp" line="383"/>
        <source>You have no permission to write here:</source>
        <translation>Nie masz uprawnień, aby tu zapisywać:</translation>
    </message>
    <message>
        <location filename="../../KvantumManager.cpp" line="80"/>
        <location filename="../../KvantumManager.cpp" line="86"/>
        <source>Follow Style</source>
        <translation>Zgodnie ze stylem</translation>
    </message>
    <message>
        <location filename="../../KvantumManager.cpp" line="81"/>
        <source>Icon Only</source>
        <translation>Tylko ikona</translation>
    </message>
    <message>
        <location filename="../../KvantumManager.cpp" line="82"/>
        <source>Text Only</source>
        <translation>Tylko tekst</translation>
    </message>
    <message>
        <location filename="../../KvantumManager.cpp" line="83"/>
        <source>Text Beside Icon</source>
        <translation>Tekst przy ikonie</translation>
    </message>
    <message>
        <location filename="../../KvantumManager.cpp" line="84"/>
        <source>Text Under Icon</source>
        <translation>Tekst pod ikoną</translation>
    </message>
    <message>
        <location filename="../../KvantumManager.cpp" line="87"/>
        <source>KDE Layout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumManager.cpp" line="88"/>
        <source>Gnome Layout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumManager.cpp" line="89"/>
        <source>Mac Layout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumManager.cpp" line="90"/>
        <source>Windows Layout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumManager.cpp" line="91"/>
        <source>Android Layout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumManager.cpp" line="93"/>
        <source>Titlebar</source>
        <translation>Pasek tytułu</translation>
    </message>
    <message>
        <location filename="../../KvantumManager.cpp" line="94"/>
        <source>Menubar</source>
        <translation>Pasek menu</translation>
    </message>
    <message>
        <location filename="../../KvantumManager.cpp" line="95"/>
        <source>Menubar and primary toolbar</source>
        <translation>Pasek menu i główny pasek narzędzi</translation>
    </message>
    <message>
        <location filename="../../KvantumManager.cpp" line="96"/>
        <source>Anywhere possible</source>
        <translation>Wszędzie, gdzie to możliwe</translation>
    </message>
    <message>
        <location filename="../../KvantumManager.cpp" line="385"/>
        <source>Please fix that first!</source>
        <translation>Napraw to najpierw!</translation>
    </message>
    <message>
        <location filename="../../KvantumManager.cpp" line="397"/>
        <source>This file cannot be removed:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumManager.cpp" line="416"/>
        <location filename="../../KvantumManager.cpp" line="427"/>
        <source>This is not an installable Kvantum theme!</source>
        <translation>To nie jest instalowalny motyw Kvantum!</translation>
    </message>
    <message>
        <location filename="../../KvantumManager.cpp" line="417"/>
        <source>The name of an installable themes should not be &quot;Default&quot;.</source>
        <translation>Nazwa instalowanego motywu musi być inna niż &quot;Default&quot;.</translation>
    </message>
    <message>
        <location filename="../../KvantumManager.cpp" line="418"/>
        <location filename="../../KvantumManager.cpp" line="429"/>
        <location filename="../../KvantumManager.cpp" line="439"/>
        <source>Please select another directory!</source>
        <translation>Wybierz inny katalog!</translation>
    </message>
    <message>
        <location filename="../../KvantumManager.cpp" line="428"/>
        <source>Installable themes should not have # in their names.</source>
        <translation>Nazwa instalowanego motywu nie może zawierać znaku &quot;#&quot;.</translation>
    </message>
    <message>
        <location filename="../../KvantumManager.cpp" line="438"/>
        <source>This is not a Kvantum theme folder!</source>
        <translation>To nie jest folder motywu Kvantum!</translation>
    </message>
    <message>
        <location filename="../../KvantumManager.cpp" line="465"/>
        <source>The theme already exists in modified form.</source>
        <translation>Motyw już istnieje w zmodyfikowanej formie.</translation>
    </message>
    <message>
        <location filename="../../KvantumManager.cpp" line="480"/>
        <source>You have selected an installed theme folder.</source>
        <translation>Wybrano foler zainstalowanego motywu.</translation>
    </message>
    <message>
        <location filename="../../KvantumManager.cpp" line="481"/>
        <source>Please choose another directory!</source>
        <translation>Wybierz inny katalog!</translation>
    </message>
    <message>
        <location filename="../../KvantumManager.cpp" line="491"/>
        <source>The theme already exists.</source>
        <translation>Motyw już istnieje.</translation>
    </message>
    <message>
        <location filename="../../KvantumManager.cpp" line="492"/>
        <source>Do you want to overwrite it?</source>
        <translation>Czy chcesz go zastąpić?</translation>
    </message>
    <message>
        <location filename="../../KvantumManager.cpp" line="527"/>
        <source>This theme is also installed as root in:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumManager.cpp" line="529"/>
        <source>The user installation will take priority.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumManager.cpp" line="543"/>
        <source>This theme is also installed as user in:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumManager.cpp" line="545"/>
        <source>This installation will take priority.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumManager.cpp" line="645"/>
        <source>Do you really want to delete &lt;i&gt;%1&lt;/i&gt;?</source>
        <translation>Czy na pewno chcesz usunąć &lt;i&gt;%1&lt;/i&gt;?</translation>
    </message>
    <message>
        <location filename="../../KvantumManager.cpp" line="648"/>
        <source>It could not be restored unless you have a copy of it.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumManager.cpp" line="1180"/>
        <location filename="../../KvantumManager.cpp" line="1199"/>
        <source>These are the settings that can be safely changed.&lt;br&gt;For the others, click &lt;i&gt;Save&lt;/i&gt; and then edit this file:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumManager.cpp" line="1195"/>
        <location filename="../../KvantumManager.cpp" line="2388"/>
        <source>These are the settings that can be safely changed.&lt;br&gt;For the others, edit this file:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumManager.cpp" line="1577"/>
        <source>No description</source>
        <translation>Brak opisu</translation>
    </message>
    <message>
        <location filename="../../KvantumManager.cpp" line="2048"/>
        <source>A copy of the root config is created.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumManager.cpp" line="2059"/>
        <source>A copy was already created.</source>
        <translation>Kopia została już utworzona.</translation>
    </message>
    <message>
        <location filename="../../KvantumManager.cpp" line="2374"/>
        <source>Configuration saved.</source>
        <translation>Zapisano konfigurację.</translation>
    </message>
    <message>
        <location filename="../../KvantumManager.cpp" line="2481"/>
        <source>Do you want to revert to the default (root) settings of this theme?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumManager.cpp" line="2484"/>
        <source>You will lose the changes you might have made.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumManager.cpp" line="2519"/>
        <source>Restored the rool default settings of %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumManager.cpp" line="2520"/>
        <source>the default theme</source>
        <translation>domyślny motyw</translation>
    </message>
    <message>
        <location filename="../../KvantumManager.cpp" line="2657"/>
        <location filename="../../KvantumManager.cpp" line="2658"/>
        <source>About Kvantum Manager</source>
        <translation>O Kvantum Manager</translation>
    </message>
    <message>
        <location filename="../../KvantumManager.cpp" line="2657"/>
        <source>Translators</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumManager.cpp" line="2655"/>
        <source>A tool for installing, selecting&lt;br&gt;and configuring &lt;a href=&apos;https://github.com/tsujan/Kvantum&apos;&gt;Kvantum&lt;/a&gt; themes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumManager.cpp" line="2656"/>
        <source>Author: &lt;a href=&apos;mailto:tsujan2000@gmail.com?Subject=My%20Subject&apos;&gt;Pedram Pourang (aka. Tsu Jan)&lt;/a&gt; &lt;/center&gt;&lt;br&gt;</source>
        <translation>Autor: &lt;a href=&apos;mailto:tsujan2000@gmail.com?Subject=Temat&apos;&gt;Pedram Pourang (aka. Tsu Jan)&lt;/a&gt; &lt;/center&gt;&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="../../KvantumManager.cpp" line="47"/>
        <source>modified</source>
        <translation>zmodyfikowany</translation>
    </message>
    <message>
        <location filename="../../KvantumManager.cpp" line="48"/>
        <source>default</source>
        <translation>domyślny</translation>
    </message>
    <message>
        <location filename="../../KvantumManager.cpp" line="395"/>
        <source>This directory cannot be removed:</source>
        <translation>Ten katalog nie może zostać usunięty:</translation>
    </message>
    <message>
        <location filename="../../KvantumManager.cpp" line="402"/>
        <source>You might want to investigate the cause.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumManager.cpp" line="828"/>
        <location filename="../../KvantumManager.cpp" line="1988"/>
        <location filename="../../KvantumManager.cpp" line="2383"/>
        <source>Active theme:</source>
        <translation>Aktywny motyw:</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../main.cpp" line="123"/>
        <source>Kvantum</source>
        <translation>Kvantum</translation>
    </message>
    <message>
        <location filename="../../main.cpp" line="124"/>
        <source>Kvantum is not installed on your system.</source>
        <translation>Kvantum nie jest zainstalowany na Twoim systemie.</translation>
    </message>
    <message>
        <location filename="../../main.cpp" line="125"/>
        <source>Please first install the Kvantum style plugin!</source>
        <translation>Najpierw zainstaluj wtyczkę motywów Kvantum!</translation>
    </message>
</context>
</TS>
